Configuration Manager API
===============================

The configuration manager API is the principal component to configure
Caliper performance measurements from within an application. 
It provides access to various built-in measurement/reporting 
configurations. 

See :cpp:class:`cali::ConfigManager`.

API Reference
-------------------------------

.. doxygengroup:: ControlChannelAPI
   :project: caliper
   :members:
